### Name: load
### Title: Reload Saved Datasets
### Aliases: load
### Keywords: file

### ** Examples

## save all data
save(list = ls(all=TRUE), file= "all.Rdata")

## restore the saved values to the current environment
load("all.Rdata")

## restore the saved values to the user's workspace
load("all.Rdata", .GlobalEnv)

## Not run: 
##D ## print the value to see what objects were created.
##D print(load(url("http://some.where.net/R/data/kprats.rda")))
## End(Not run)


